# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/account_report/v1/account_report.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/account_report/v1/account_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2
from meshtrade.type.v1 import address_pb2 as meshtrade_dot_type_dot_v1_dot_address__pb2
from meshtrade.reporting.account_report.v1 import fee_entry_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_fee__entry__pb2
from meshtrade.reporting.account_report.v1 import income_entry_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_income__entry__pb2
from meshtrade.reporting.account_report.v1 import trading_statement_entry_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_trading__statement__entry__pb2
from meshtrade.reporting.account_report.v1 import disclaimer_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_disclaimer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:meshtrade/reporting/account_report/v1/account_report.proto\x12%meshtrade.reporting.account_report.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dmeshtrade/type/v1/token.proto\x1a\x1fmeshtrade/type/v1/address.proto\x1a\x35meshtrade/reporting/account_report/v1/fee_entry.proto\x1a\x38meshtrade/reporting/account_report/v1/income_entry.proto\x1a\x43meshtrade/reporting/account_report/v1/trading_statement_entry.proto\x1a\x36meshtrade/reporting/account_report/v1/disclaimer.proto\"\x9c\x07\n\rAccountReport\x12Y\n\x0eincome_entries\x18\x01 \x03(\x0b\x32\x32.meshtrade.reporting.account_report.v1.IncomeEntryR\rincomeEntries\x12P\n\x0b\x66\x65\x65_entries\x18\x02 \x03(\x0b\x32/.meshtrade.reporting.account_report.v1.FeeEntryR\nfeeEntries\x12x\n\x19trading_statement_entries\x18\x03 \x03(\x0b\x32<.meshtrade.reporting.account_report.v1.TradingStatementEntryR\x17tradingStatementEntries\x12G\n\x12reporting_currency\x18\x04 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x11reportingCurrency\x12S\n\x06period\x18\x05 \x01(\x0b\x32;.meshtrade.reporting.account_report.v1.AccountReport.PeriodR\x06period\x12\x43\n\x0fgeneration_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0egenerationDate\x12%\n\x0e\x61\x63\x63ount_number\x18\x07 \x01(\tR\raccountNumber\x12S\n\x0b\x64isclaimers\x18\x08 \x03(\x0b\x32\x31.meshtrade.reporting.account_report.v1.DisclaimerR\x0b\x64isclaimers\x12\x41\n\x0e\x63lient_address\x18\t \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\rclientAddress\x12\x1f\n\x0b\x63lient_name\x18\n \x01(\tR\nclientName\x12\x1c\n\tcopyright\x18\x0b \x01(\tR\tcopyright\x1a\x82\x01\n\x06Period\x12=\n\x0cperiod_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bperiodStart\x12\x39\n\nperiod_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tperiodEndBy\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.account_report.v1.account_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1'
  _globals['_ACCOUNTREPORT']._serialized_start=437
  _globals['_ACCOUNTREPORT']._serialized_end=1361
  _globals['_ACCOUNTREPORT_PERIOD']._serialized_start=1231
  _globals['_ACCOUNTREPORT_PERIOD']._serialized_end=1361
# @@protoc_insertion_point(module_scope)
