# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/ledger/transaction/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/ledger/transaction/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2
from meshtrade.ledger.transaction.v1 import transaction_state_pb2 as meshtrade_dot_ledger_dot_transaction_dot_v1_dot_transaction__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-meshtrade/ledger/transaction/v1/service.proto\x12\x1fmeshtrade.ledger.transaction.v1\x1a\x1b\x62uf/validate/validate.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\x1a\x37meshtrade/ledger/transaction/v1/transaction_state.proto\"t\n\x1aGetTransactionStateRequest\x12V\n\x04name\x18\x01 \x01(\tBB\xbaH?r:25^transactions/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01\'\xc8\x01\x01R\x04name\"f\n\x1bGetTransactionStateResponse\x12G\n\x05state\x18\x01 \x01(\x0e\x32\x31.meshtrade.ledger.transaction.v1.TransactionStateR\x05state\"x\n\x1eMonitorTransactionStateRequest\x12V\n\x04name\x18\x01 \x01(\tBB\xbaH?r:25^transactions/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01\'\xc8\x01\x01R\x04name\"j\n\x1fMonitorTransactionStateResponse\x12G\n\x05state\x18\x01 \x01(\x0e\x32\x31.meshtrade.ledger.transaction.v1.TransactionStateR\x05state2\x80\x03\n\x12TransactionService\x12\xac\x01\n\x13GetTransactionState\x12;.meshtrade.ledger.transaction.v1.GetTransactionStateRequest\x1a<.meshtrade.ledger.transaction.v1.GetTransactionStateResponse\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x9f\xab\x03\xc1\x9f\xab\x03\xc2\x9f\xab\x03\xc3\x9f\xab\x03\x12\xba\x01\n\x17MonitorTransactionState\x12?.meshtrade.ledger.transaction.v1.MonitorTransactionStateRequest\x1a@.meshtrade.ledger.transaction.v1.MonitorTransactionStateResponse\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x9f\xab\x03\xc1\x9f\xab\x03\xc2\x9f\xab\x03\xc3\x9f\xab\x03\x30\x01\x42j\n&co.meshtrade.api.ledger.transaction.v1Z@github.com/meshtrade/api/go/ledger/transaction/v1;transaction_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.ledger.transaction.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&co.meshtrade.api.ledger.transaction.v1Z@github.com/meshtrade/api/go/ledger/transaction/v1;transaction_v1'
  _globals['_GETTRANSACTIONSTATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETTRANSACTIONSTATEREQUEST'].fields_by_name['name']._serialized_options = b'\272H?r:25^transactions/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001\'\310\001\001'
  _globals['_MONITORTRANSACTIONSTATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_MONITORTRANSACTIONSTATEREQUEST'].fields_by_name['name']._serialized_options = b'\272H?r:25^transactions/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001\'\310\001\001'
  _globals['_TRANSACTIONSERVICE'].methods_by_name['GetTransactionState']._loaded_options = None
  _globals['_TRANSACTIONSERVICE'].methods_by_name['GetTransactionState']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\237\253\003\301\237\253\003\302\237\253\003\303\237\253\003'
  _globals['_TRANSACTIONSERVICE'].methods_by_name['MonitorTransactionState']._loaded_options = None
  _globals['_TRANSACTIONSERVICE'].methods_by_name['MonitorTransactionState']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\237\253\003\301\237\253\003\302\237\253\003\303\237\253\003'
  _globals['_GETTRANSACTIONSTATEREQUEST']._serialized_start=241
  _globals['_GETTRANSACTIONSTATEREQUEST']._serialized_end=357
  _globals['_GETTRANSACTIONSTATERESPONSE']._serialized_start=359
  _globals['_GETTRANSACTIONSTATERESPONSE']._serialized_end=461
  _globals['_MONITORTRANSACTIONSTATEREQUEST']._serialized_start=463
  _globals['_MONITORTRANSACTIONSTATEREQUEST']._serialized_end=583
  _globals['_MONITORTRANSACTIONSTATERESPONSE']._serialized_start=585
  _globals['_MONITORTRANSACTIONSTATERESPONSE']._serialized_end=691
  _globals['_TRANSACTIONSERVICE']._serialized_start=694
  _globals['_TRANSACTIONSERVICE']._serialized_end=1078
# @@protoc_insertion_point(module_scope)
