# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/account_report/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/account_report/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2
from meshtrade.reporting.account_report.v1 import account_report_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3meshtrade/reporting/account_report/v1/service.proto\x12%meshtrade.reporting.account_report.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\x1a:meshtrade/reporting/account_report/v1/account_report.proto\x1a\x1dmeshtrade/type/v1/token.proto\"\xa7\x03\n\x17GetAccountReportRequest\x12\x39\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tB\x12\xbaH\x0fr\r2\x0b^1[0-9]{6}$R\raccountNumber\x12\x45\n\x0cperiod_start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x0bperiodStart\x12\x41\n\nperiod_end\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\tperiodEnd\x12T\n\x15reporting_asset_token\x18\x04 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenB\x06\xbaH\x03\xc8\x01\x01R\x13reportingAssetToken:q\xbaHn\x1al\n\x18period.chronological.get\x12+period_end must be on or after period_start\x1a#this.period_end > this.period_start\"\xaf\x03\n\x1cGetExcelAccountReportRequest\x12\x39\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tB\x12\xbaH\x0fr\r2\x0b^1[0-9]{6}$R\raccountNumber\x12\x45\n\x0cperiod_start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x0bperiodStart\x12\x41\n\nperiod_end\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\tperiodEnd\x12T\n\x15reporting_asset_token\x18\x04 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenB\x06\xbaH\x03\xc8\x01\x01R\x13reportingAssetToken:t\xbaHq\x1ao\n\x1aperiod.chronological.excel\x12+period_end must be on or after period_start\x1a$this.period_end >= this.period_start\"B\n\x1dGetExcelAccountReportResponse\x12!\n\x0c\x65xcel_base64\x18\x01 \x01(\tR\x0b\x65xcelBase642\xee\x02\n\x14\x41\x63\x63ountReportService\x12\x9c\x01\n\x10GetAccountReport\x12>.meshtrade.reporting.account_report.v1.GetAccountReportRequest\x1a\x34.meshtrade.reporting.account_report.v1.AccountReport\"\x12\xa0\xb5\x18\x01\xaa\xb5\x18\n\n\x08\x80\x9b\xee\x02\x81\x9b\xee\x02\x12\xb6\x01\n\x15GetExcelAccountReport\x12\x43.meshtrade.reporting.account_report.v1.GetExcelAccountReportRequest\x1a\x44.meshtrade.reporting.account_report.v1.GetExcelAccountReportResponse\"\x12\xa0\xb5\x18\x01\xaa\xb5\x18\n\n\x08\x80\x9b\xee\x02\x81\x9b\xee\x02\x42y\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.account_report.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1'
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['account_number']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['account_number']._serialized_options = b'\272H\017r\r2\013^1[0-9]{6}$'
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['period_start']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['period_start']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['period_end']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['period_end']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['reporting_asset_token']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST'].fields_by_name['reporting_asset_token']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETACCOUNTREPORTREQUEST']._loaded_options = None
  _globals['_GETACCOUNTREPORTREQUEST']._serialized_options = b'\272Hn\032l\n\030period.chronological.get\022+period_end must be on or after period_start\032#this.period_end > this.period_start'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['account_number']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['account_number']._serialized_options = b'\272H\017r\r2\013^1[0-9]{6}$'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['period_start']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['period_start']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['period_end']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['period_end']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['reporting_asset_token']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['reporting_asset_token']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._serialized_options = b'\272Hq\032o\n\032period.chronological.excel\022+period_end must be on or after period_start\032$this.period_end >= this.period_start'
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetAccountReport']._loaded_options = None
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetAccountReport']._serialized_options = b'\240\265\030\001\252\265\030\n\n\010\200\233\356\002\201\233\356\002'
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetExcelAccountReport']._loaded_options = None
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetExcelAccountReport']._serialized_options = b'\240\265\030\001\252\265\030\n\n\010\200\233\356\002\201\233\356\002'
  _globals['_GETACCOUNTREPORTREQUEST']._serialized_start=321
  _globals['_GETACCOUNTREPORTREQUEST']._serialized_end=744
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._serialized_start=747
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._serialized_end=1178
  _globals['_GETEXCELACCOUNTREPORTRESPONSE']._serialized_start=1180
  _globals['_GETEXCELACCOUNTREPORTRESPONSE']._serialized_end=1246
  _globals['_ACCOUNTREPORTSERVICE']._serialized_start=1249
  _globals['_ACCOUNTREPORTSERVICE']._serialized_end=1615
# @@protoc_insertion_point(module_scope)
