from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Unit(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNIT_UNSPECIFIED: _ClassVar[Unit]
    UNIT_NULL: _ClassVar[Unit]
    UNIT_NOTE: _ClassVar[Unit]
    UNIT_SHARE: _ClassVar[Unit]
    UNIT_PREFERENCE_SHARE: _ClassVar[Unit]
    UNIT_BOND: _ClassVar[Unit]
    UNIT_BILL: _ClassVar[Unit]
    UNIT_CONTRACT: _ClassVar[Unit]
    UNIT_OPTION: _ClassVar[Unit]
    UNIT_TOKEN: _ClassVar[Unit]
    UNIT_BARREL: _ClassVar[Unit]
    UNIT_GRAM: _ClassVar[Unit]
    UNIT_KILOGRAM: _ClassVar[Unit]
    UNIT_METRIC_TON: _ClassVar[Unit]
    UNIT_OUNCE: _ClassVar[Unit]
    UNIT_HALF_OUNCE: _ClassVar[Unit]
    UNIT_QUARTER_OUNCE: _ClassVar[Unit]
    UNIT_ONE_TENTH_OUNCE: _ClassVar[Unit]
    UNIT_ONE_HUNDREDTH_OUNCE: _ClassVar[Unit]
UNIT_UNSPECIFIED: Unit
UNIT_NULL: Unit
UNIT_NOTE: Unit
UNIT_SHARE: Unit
UNIT_PREFERENCE_SHARE: Unit
UNIT_BOND: Unit
UNIT_BILL: Unit
UNIT_CONTRACT: Unit
UNIT_OPTION: Unit
UNIT_TOKEN: Unit
UNIT_BARREL: Unit
UNIT_GRAM: Unit
UNIT_KILOGRAM: Unit
UNIT_METRIC_TON: Unit
UNIT_OUNCE: Unit
UNIT_HALF_OUNCE: Unit
UNIT_QUARTER_OUNCE: Unit
UNIT_ONE_TENTH_OUNCE: Unit
UNIT_ONE_HUNDREDTH_OUNCE: Unit
