# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/option/v1/method_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/option/v1/method_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%meshtrade/option/v1/method_type.proto\x12\x13meshtrade.option.v1\x1a google/protobuf/descriptor.proto*V\n\nMethodType\x12\x1b\n\x17METHOD_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10METHOD_TYPE_READ\x10\x01\x12\x15\n\x11METHOD_TYPE_WRITE\x10\x02:b\n\x0bmethod_type\x12\x1e.google.protobuf.MethodOptions\x18\xd4\x86\x03 \x01(\x0e\x32\x1f.meshtrade.option.v1.MethodTypeR\nmethodTypeBM\n\x1a\x63o.meshtrade.api.option.v1Z/github.com/meshtrade/api/go/option/v1;option_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.option.v1.method_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032co.meshtrade.api.option.v1Z/github.com/meshtrade/api/go/option/v1;option_v1'
  _globals['_METHODTYPE']._serialized_start=96
  _globals['_METHODTYPE']._serialized_end=182
# @@protoc_insertion_point(module_scope)
