# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.trading.limit_order.v1 import limit_order_pb2 as meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2
from meshtrade.trading.limit_order.v1 import service_pb2 as meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2


class LimitOrderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetLimitOrder = channel.unary_unary(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/GetLimitOrder',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
                _registered_method=True)


class LimitOrderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetLimitOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LimitOrderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetLimitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLimitOrder,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.trading.limit_order.v1.LimitOrderService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.trading.limit_order.v1.LimitOrderService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class LimitOrderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/GetLimitOrder',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
