# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.compliance.client.v1 import client_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,meshtrade/compliance/client/v1/service.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\x1a+meshtrade/compliance/client/v1/client.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\"e\n\x10GetClientRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\xbaH:r520^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x04name\"]\n\x13\x43reateClientRequest\x12\x46\n\x06\x63lient\x18\x01 \x01(\x0b\x32&.meshtrade.compliance.client.v1.ClientB\x06\xbaH\x03\xc8\x01\x01R\x06\x63lient\"\x14\n\x12ListClientsRequest\"W\n\x13ListClientsResponse\x12@\n\x07\x63lients\x18\x01 \x03(\x0b\x32&.meshtrade.compliance.client.v1.ClientR\x07\x63lients2\x9e\x03\n\rClientService\x12}\n\x0c\x43reateClient\x12\x33.meshtrade.compliance.client.v1.CreateClientRequest\x1a&.meshtrade.compliance.client.v1.Client\"\x10\xa0\xb5\x18\x02\xaa\xb5\x18\x08\n\x06\x80\x89z\x82\x89z\x12}\n\tGetClient\x12\x30.meshtrade.compliance.client.v1.GetClientRequest\x1a&.meshtrade.compliance.client.v1.Client\"\x16\xa0\xb5\x18\x01\xaa\xb5\x18\x0e\n\x0c\x80\x89z\x81\x89z\x82\x89z\x83\x89z\x12\x8e\x01\n\x0bListClients\x12\x32.meshtrade.compliance.client.v1.ListClientsRequest\x1a\x33.meshtrade.compliance.client.v1.ListClientsResponse\"\x16\xa0\xb5\x18\x01\xaa\xb5\x18\x0e\n\x0c\x80\x89z\x81\x89z\x82\x89z\x83\x89zBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_GETCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\272H:r520^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_CREATECLIENTREQUEST'].fields_by_name['client']._loaded_options = None
  _globals['_CREATECLIENTREQUEST'].fields_by_name['client']._serialized_options = b'\272H\003\310\001\001'
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._serialized_options = b'\240\265\030\002\252\265\030\010\n\006\200\211z\202\211z'
  _globals['_CLIENTSERVICE'].methods_by_name['GetClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['GetClient']._serialized_options = b'\240\265\030\001\252\265\030\016\n\014\200\211z\201\211z\202\211z\203\211z'
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._serialized_options = b'\240\265\030\001\252\265\030\016\n\014\200\211z\201\211z\202\211z\203\211z'
  _globals['_GETCLIENTREQUEST']._serialized_start=227
  _globals['_GETCLIENTREQUEST']._serialized_end=328
  _globals['_CREATECLIENTREQUEST']._serialized_start=330
  _globals['_CREATECLIENTREQUEST']._serialized_end=423
  _globals['_LISTCLIENTSREQUEST']._serialized_start=425
  _globals['_LISTCLIENTSREQUEST']._serialized_end=445
  _globals['_LISTCLIENTSRESPONSE']._serialized_start=447
  _globals['_LISTCLIENTSRESPONSE']._serialized_end=534
  _globals['_CLIENTSERVICE']._serialized_start=537
  _globals['_CLIENTSERVICE']._serialized_end=951
# @@protoc_insertion_point(module_scope)
