# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/studio/instrument/v1/unit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/studio/instrument/v1/unit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)meshtrade/studio/instrument/v1/unit.proto\x12\x1emeshtrade.studio.instrument.v1*\xf4\x02\n\x04Unit\x12\x14\n\x10UNIT_UNSPECIFIED\x10\x00\x12\r\n\tUNIT_NULL\x10\x01\x12\r\n\tUNIT_NOTE\x10\x02\x12\x0e\n\nUNIT_SHARE\x10\x03\x12\x19\n\x15UNIT_PREFERENCE_SHARE\x10\x04\x12\r\n\tUNIT_BOND\x10\x05\x12\r\n\tUNIT_BILL\x10\x06\x12\x11\n\rUNIT_CONTRACT\x10\x07\x12\x0f\n\x0bUNIT_OPTION\x10\x08\x12\x0e\n\nUNIT_TOKEN\x10\t\x12\x0f\n\x0bUNIT_BARREL\x10\n\x12\r\n\tUNIT_GRAM\x10\x0b\x12\x11\n\rUNIT_KILOGRAM\x10\x0c\x12\x13\n\x0fUNIT_METRIC_TON\x10\r\x12\x0e\n\nUNIT_OUNCE\x10\x0e\x12\x13\n\x0fUNIT_HALF_OUNCE\x10\x0f\x12\x16\n\x12UNIT_QUARTER_OUNCE\x10\x10\x12\x18\n\x14UNIT_ONE_TENTH_OUNCE\x10\x11\x12\x1c\n\x18UNIT_ONE_HUNDREDTH_OUNCE\x10\x12\x42g\n%co.meshtrade.api.studio.instrument.v1Z>github.com/meshtrade/api/go/studio/instrument/v1;instrument_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.studio.instrument.v1.unit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.studio.instrument.v1Z>github.com/meshtrade/api/go/studio/instrument/v1;instrument_v1'
  _globals['_UNIT']._serialized_start=78
  _globals['_UNIT']._serialized_end=450
# @@protoc_insertion_point(module_scope)
