# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/wallet/account/v1/account.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/wallet/account/v1/account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.type.v1 import ledger_pb2 as meshtrade_dot_type_dot_v1_dot_ledger__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2
from meshtrade.studio.instrument.v1 import instrument_type_pb2 as meshtrade_dot_studio_dot_instrument_dot_v1_dot_instrument__type__pb2
from meshtrade.studio.instrument.v1 import unit_pb2 as meshtrade_dot_studio_dot_instrument_dot_v1_dot_unit__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)meshtrade/wallet/account/v1/account.proto\x12\x1bmeshtrade.wallet.account.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1emeshtrade/type/v1/ledger.proto\x1a\x1emeshtrade/type/v1/amount.proto\x1a\x34meshtrade/studio/instrument/v1/instrument_type.proto\x1a)meshtrade/studio/instrument/v1/unit.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbd\x06\n\x07\x41\x63\x63ount\x12\xc0\x01\n\x04name\x18\x01 \x01(\tB\xab\x01\xbaH\xa7\x01\xba\x01\xa3\x01\n\x14name.format.optional\x12\x35name must be empty or in the format accounts/{ULIDv2}\x1aTsize(this) == 0 || this.matches(\'^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name\x12R\n\x05owner\x18\x02 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05owner\x12\xab\x01\n\x06number\x18\x05 \x01(\tB\x92\x01\xbaH\x8e\x01\xba\x01\x8a\x01\n\x16number.format.optional\x12@number must be empty or a 7-digit account number starting with 1\x1a.size(this) == 0 || this.matches(\'^1[0-9]{6}$\')R\x06number\x12%\n\tledger_id\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01R\x08ledgerId\x12@\n\x06ledger\x18\x07 \x01(\x0e\x32\x19.meshtrade.type.v1.LedgerB\r\xbaH\n\x82\x01\x04\x10\x01 \x00\xc8\x01\x01R\x06ledger\x12\x30\n\x0c\x64isplay_name\x18\x08 \x01(\tB\r\xbaH\nr\x05\x10\x01\x18\xff\x01\xc8\x01\x01R\x0b\x64isplayName\x12O\n\x16live_data_retrieved_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13liveDataRetrievedAt\x12?\n\x05state\x18\n \x01(\x0e\x32).meshtrade.wallet.account.v1.AccountStateR\x05state\x12@\n\x08\x62\x61lances\x18\x0b \x03(\x0b\x32$.meshtrade.wallet.account.v1.BalanceR\x08\x62\x61lances\"\xa6\x01\n\x12InstrumentMetaData\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x42\n\x04type\x18\x02 \x01(\x0e\x32..meshtrade.studio.instrument.v1.InstrumentTypeR\x04type\x12\x38\n\x04unit\x18\x03 \x01(\x0e\x32$.meshtrade.studio.instrument.v1.UnitR\x04unit\"\x9e\x01\n\x07\x42\x61lance\x12\x31\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x06\x61mount\x12`\n\x13instrument_metadata\x18\x02 \x01(\x0b\x32/.meshtrade.wallet.account.v1.InstrumentMetaDataR\x12instrumentMetadata*_\n\x0c\x41\x63\x63ountState\x12\x1d\n\x19\x41\x43\x43OUNT_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41\x43\x43OUNT_STATE_CLOSED\x10\x01\x12\x16\n\x12\x41\x43\x43OUNT_STATE_OPEN\x10\x02\x42^\n\"co.meshtrade.api.wallet.account.v1Z8github.com/meshtrade/api/go/wallet/account/v1;account_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.wallet.account.v1.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"co.meshtrade.api.wallet.account.v1Z8github.com/meshtrade/api/go/wallet/account/v1;account_v1'
  _globals['_ACCOUNT'].fields_by_name['name']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['name']._serialized_options = b'\272H\247\001\272\001\243\001\n\024name.format.optional\0225name must be empty or in the format accounts/{ULIDv2}\032Tsize(this) == 0 || this.matches(\'^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_ACCOUNT'].fields_by_name['owner']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['owner']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_ACCOUNT'].fields_by_name['number']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['number']._serialized_options = b'\272H\216\001\272\001\212\001\n\026number.format.optional\022@number must be empty or a 7-digit account number starting with 1\032.size(this) == 0 || this.matches(\'^1[0-9]{6}$\')'
  _globals['_ACCOUNT'].fields_by_name['ledger_id']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['ledger_id']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_ACCOUNT'].fields_by_name['ledger']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['ledger']._serialized_options = b'\272H\n\202\001\004\020\001 \000\310\001\001'
  _globals['_ACCOUNT'].fields_by_name['display_name']._loaded_options = None
  _globals['_ACCOUNT'].fields_by_name['display_name']._serialized_options = b'\272H\nr\005\020\001\030\377\001\310\001\001'
  _globals['_ACCOUNTSTATE']._serialized_start=1459
  _globals['_ACCOUNTSTATE']._serialized_end=1554
  _globals['_ACCOUNT']._serialized_start=298
  _globals['_ACCOUNT']._serialized_end=1127
  _globals['_INSTRUMENTMETADATA']._serialized_start=1130
  _globals['_INSTRUMENTMETADATA']._serialized_end=1296
  _globals['_BALANCE']._serialized_start=1299
  _globals['_BALANCE']._serialized_end=1457
# @@protoc_insertion_point(module_scope)
