# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/studio/instrument/v1/instrument_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/studio/instrument/v1/instrument_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4meshtrade/studio/instrument/v1/instrument_type.proto\x12\x1emeshtrade.studio.instrument.v1*\xfc\x06\n\x0eInstrumentType\x12\x1f\n\x1bINSTRUMENT_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15INSTRUMENT_TYPE_OTHER\x10\x01\x12\x19\n\x15INSTRUMENT_TYPE_SHARE\x10\x02\x12$\n INSTRUMENT_TYPE_PREFERENCE_SHARE\x10\x03\x12\x18\n\x14INSTRUMENT_TYPE_BOND\x10\x04\x12\x17\n\x13INSTRUMENT_TYPE_ETF\x10\x05\x12\x17\n\x13INSTRUMENT_TYPE_ETN\x10\x06\x12\x17\n\x13INSTRUMENT_TYPE_AMC\x10\x07\x12\x1e\n\x1aINSTRUMENT_TYPE_UNIT_TRUST\x10\x08\x12#\n\x1fINSTRUMENT_TYPE_CRYPTO_CURRENCY\x10\t\x12!\n\x1dINSTRUMENT_TYPE_FIAT_CURRENCY\x10\n\x12\x1a\n\x16INSTRUMENT_TYPE_RIGHTS\x10\x0b\x12\x18\n\x14INSTRUMENT_TYPE_GOLD\x10\x0c\x12\x1a\n\x16INSTRUMENT_TYPE_SILVER\x10\r\x12\x1c\n\x18INSTRUMENT_TYPE_PLATINUM\x10\x0e\x12\x1d\n\x19INSTRUMENT_TYPE_PALLADIUM\x10\x0f\x12\x1d\n\x19INSTRUMENT_TYPE_CRUDE_OIL\x10\x10\x12\x1f\n\x1bINSTRUMENT_TYPE_NATURAL_GAS\x10\x11\x12\x1a\n\x16INSTRUMENT_TYPE_COPPER\x10\x12\x12\x18\n\x14INSTRUMENT_TYPE_CORN\x10\x13\x12\x19\n\x15INSTRUMENT_TYPE_WHEAT\x10\x14\x12\x1c\n\x18INSTRUMENT_TYPE_SOYBEANS\x10\x15\x12#\n\x1fINSTRUMENT_TYPE_FIAT_STABLECOIN\x10\x16\x12%\n!INSTRUMENT_TYPE_MONEY_MARKET_FUND\x10\x17\x12\x30\n,INSTRUMENT_TYPE_MONEY_MARKET_FUND_STABLECOIN\x10\x18\x12%\n!INSTRUMENT_TYPE_ENDOWMENT_WRAPPER\x10\x19\x12\x18\n\x14INSTRUMENT_TYPE_FUND\x10\x1a\x12#\n\x1fINSTRUMENT_TYPE_FUND_STABLECOIN\x10\x1b\x42g\n%co.meshtrade.api.studio.instrument.v1Z>github.com/meshtrade/api/go/studio/instrument/v1;instrument_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.studio.instrument.v1.instrument_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.studio.instrument.v1Z>github.com/meshtrade/api/go/studio/instrument/v1;instrument_v1'
  _globals['_INSTRUMENTTYPE']._serialized_start=89
  _globals['_INSTRUMENTTYPE']._serialized_end=981
# @@protoc_insertion_point(module_scope)
