# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/group/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/group/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.group.v1 import group_pb2 as meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2
from meshtrade.type.v1 import sorting_pb2 as meshtrade_dot_type_dot_v1_dot_sorting__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$meshtrade/iam/group/v1/service.proto\x12\x16meshtrade.iam.group.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\"meshtrade/iam/group/v1/group.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\x1a\x1fmeshtrade/type/v1/sorting.proto\"Q\n\x12\x43reateGroupRequest\x12;\n\x05group\x18\x01 \x01(\x0b\x32\x1d.meshtrade.iam.group.v1.GroupB\x06\xbaH\x03\xc8\x01\x01R\x05group\"Q\n\x12UpdateGroupRequest\x12;\n\x05group\x18\x01 \x01(\x0b\x32\x1d.meshtrade.iam.group.v1.GroupB\x06\xbaH\x03\xc8\x01\x01R\x05group\"\xc3\x02\n\x11ListGroupsRequest\x12K\n\x07sorting\x18\x01 \x01(\x0b\x32\x31.meshtrade.iam.group.v1.ListGroupsRequest.SortingR\x07sorting\x1a\xe0\x01\n\x07Sorting\x12\x9d\x01\n\x05\x66ield\x18\x01 \x01(\tB\x86\x01\xbaH\x82\x01r\x16R\x00R\x04nameR\x0c\x64isplay_name\xba\x01g\n\x0b\x66ield.valid\x12\x32\x66ield must be one of: name, display_name, or empty\x1a$this in [\'\', \'name\', \'display_name\']R\x05\x66ield\x12\x35\n\x05order\x18\x02 \x01(\x0e\x32\x1f.meshtrade.type.v1.SortingOrderR\x05order\"K\n\x12ListGroupsResponse\x12\x35\n\x06groups\x18\x01 \x03(\x0b\x32\x1d.meshtrade.iam.group.v1.GroupR\x06groups\"\xf0\x04\n\x13SearchGroupsRequest\x12\x93\x01\n\x0c\x64isplay_name\x18\x01 \x01(\tBp\xbaHmr\x03\x18\xff\x01\xba\x01\x65\n\x17\x64isplay_name.max_length\x12\x37\x64isplay_name search term must not exceed 255 characters\x1a\x11size(this) <= 255R\x0b\x64isplayName\x12\x90\x01\n\x0b\x64\x65scription\x18\x02 \x01(\tBn\xbaHkr\x03\x18\xff\x01\xba\x01\x63\n\x16\x64\x65scription.max_length\x12\x36\x64\x65scription search term must not exceed 255 characters\x1a\x11size(this) <= 255R\x0b\x64\x65scription\x12M\n\x07sorting\x18\x03 \x01(\x0b\x32\x33.meshtrade.iam.group.v1.SearchGroupsRequest.SortingR\x07sorting\x1a\xe0\x01\n\x07Sorting\x12\x9d\x01\n\x05\x66ield\x18\x01 \x01(\tB\x86\x01\xbaH\x82\x01r\x16R\x00R\x04nameR\x0c\x64isplay_name\xba\x01g\n\x0b\x66ield.valid\x12\x32\x66ield must be one of: name, display_name, or empty\x1a$this in [\'\', \'name\', \'display_name\']R\x05\x66ield\x12\x35\n\x05order\x18\x02 \x01(\x0e\x32\x1f.meshtrade.type.v1.SortingOrderR\x05order\"M\n\x14SearchGroupsResponse\x12\x35\n\x06groups\x18\x01 \x03(\x0b\x32\x1d.meshtrade.iam.group.v1.GroupR\x06groups\"\xf3\x02\n\x0fGetGroupRequest\x12\xdf\x02\n\x04name\x18\x01 \x01(\tB\xca\x02\xbaH\xc6\x02r3\x10\x01\x32/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\xba\x01W\n\rname.required\x12\x36name is required and must be in format groups/{ULIDv2}\x1a\x0esize(this) > 0\xba\x01\xb3\x01\n\x0bname.format\x12\x63name must be in format groups/{ULIDv2} where ulidv2 is exactly 26 uppercase alphanumeric characters\x1a?this.matches(\'^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name2\xe3\x04\n\x0cGroupService\x12l\n\x0b\x43reateGroup\x12*.meshtrade.iam.group.v1.CreateGroupRequest\x1a\x1d.meshtrade.iam.group.v1.Group\"\x12\xa0\xb5\x18\x02\xaa\xb5\x18\n\n\x08\xc0\x8d\xb7\x01\xc4\x8d\xb7\x01\x12l\n\x0bUpdateGroup\x12*.meshtrade.iam.group.v1.UpdateGroupRequest\x1a\x1d.meshtrade.iam.group.v1.Group\"\x12\xa0\xb5\x18\x02\xaa\xb5\x18\n\n\x08\xc0\x8d\xb7\x01\xc4\x8d\xb7\x01\x12\x7f\n\nListGroups\x12).meshtrade.iam.group.v1.ListGroupsRequest\x1a*.meshtrade.iam.group.v1.ListGroupsResponse\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc4\x8d\xb7\x01\xc5\x8d\xb7\x01\x12\x85\x01\n\x0cSearchGroups\x12+.meshtrade.iam.group.v1.SearchGroupsRequest\x1a,.meshtrade.iam.group.v1.SearchGroupsResponse\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc4\x8d\xb7\x01\xc5\x8d\xb7\x01\x12n\n\x08GetGroup\x12\'.meshtrade.iam.group.v1.GetGroupRequest\x1a\x1d.meshtrade.iam.group.v1.Group\"\x1a\xa0\xb5\x18\x01\xaa\xb5\x18\x12\n\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc4\x8d\xb7\x01\xc5\x8d\xb7\x01\x42R\n\x1d\x63o.meshtrade.api.iam.group.v1Z1github.com/meshtrade/api/go/iam/group/v1;group_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.group.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035co.meshtrade.api.iam.group.v1Z1github.com/meshtrade/api/go/iam/group/v1;group_v1'
  _globals['_CREATEGROUPREQUEST'].fields_by_name['group']._loaded_options = None
  _globals['_CREATEGROUPREQUEST'].fields_by_name['group']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEGROUPREQUEST'].fields_by_name['group']._loaded_options = None
  _globals['_UPDATEGROUPREQUEST'].fields_by_name['group']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTGROUPSREQUEST_SORTING'].fields_by_name['field']._loaded_options = None
  _globals['_LISTGROUPSREQUEST_SORTING'].fields_by_name['field']._serialized_options = b'\272H\202\001r\026R\000R\004nameR\014display_name\272\001g\n\013field.valid\0222field must be one of: name, display_name, or empty\032$this in [\'\', \'name\', \'display_name\']'
  _globals['_SEARCHGROUPSREQUEST_SORTING'].fields_by_name['field']._loaded_options = None
  _globals['_SEARCHGROUPSREQUEST_SORTING'].fields_by_name['field']._serialized_options = b'\272H\202\001r\026R\000R\004nameR\014display_name\272\001g\n\013field.valid\0222field must be one of: name, display_name, or empty\032$this in [\'\', \'name\', \'display_name\']'
  _globals['_SEARCHGROUPSREQUEST'].fields_by_name['display_name']._loaded_options = None
  _globals['_SEARCHGROUPSREQUEST'].fields_by_name['display_name']._serialized_options = b'\272Hmr\003\030\377\001\272\001e\n\027display_name.max_length\0227display_name search term must not exceed 255 characters\032\021size(this) <= 255'
  _globals['_SEARCHGROUPSREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_SEARCHGROUPSREQUEST'].fields_by_name['description']._serialized_options = b'\272Hkr\003\030\377\001\272\001c\n\026description.max_length\0226description search term must not exceed 255 characters\032\021size(this) <= 255'
  _globals['_GETGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\272H\306\002r3\020\0012/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\272\001W\n\rname.required\0226name is required and must be in format groups/{ULIDv2}\032\016size(this) > 0\272\001\263\001\n\013name.format\022cname must be in format groups/{ULIDv2} where ulidv2 is exactly 26 uppercase alphanumeric characters\032?this.matches(\'^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_GROUPSERVICE'].methods_by_name['CreateGroup']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['CreateGroup']._serialized_options = b'\240\265\030\002\252\265\030\n\n\010\300\215\267\001\304\215\267\001'
  _globals['_GROUPSERVICE'].methods_by_name['UpdateGroup']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['UpdateGroup']._serialized_options = b'\240\265\030\002\252\265\030\n\n\010\300\215\267\001\304\215\267\001'
  _globals['_GROUPSERVICE'].methods_by_name['ListGroups']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['ListGroups']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\215\267\001\301\215\267\001\304\215\267\001\305\215\267\001'
  _globals['_GROUPSERVICE'].methods_by_name['SearchGroups']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['SearchGroups']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\215\267\001\301\215\267\001\304\215\267\001\305\215\267\001'
  _globals['_GROUPSERVICE'].methods_by_name['GetGroup']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['GetGroup']._serialized_options = b'\240\265\030\001\252\265\030\022\n\020\300\215\267\001\301\215\267\001\304\215\267\001\305\215\267\001'
  _globals['_CREATEGROUPREQUEST']._serialized_start=235
  _globals['_CREATEGROUPREQUEST']._serialized_end=316
  _globals['_UPDATEGROUPREQUEST']._serialized_start=318
  _globals['_UPDATEGROUPREQUEST']._serialized_end=399
  _globals['_LISTGROUPSREQUEST']._serialized_start=402
  _globals['_LISTGROUPSREQUEST']._serialized_end=725
  _globals['_LISTGROUPSREQUEST_SORTING']._serialized_start=501
  _globals['_LISTGROUPSREQUEST_SORTING']._serialized_end=725
  _globals['_LISTGROUPSRESPONSE']._serialized_start=727
  _globals['_LISTGROUPSRESPONSE']._serialized_end=802
  _globals['_SEARCHGROUPSREQUEST']._serialized_start=805
  _globals['_SEARCHGROUPSREQUEST']._serialized_end=1429
  _globals['_SEARCHGROUPSREQUEST_SORTING']._serialized_start=501
  _globals['_SEARCHGROUPSREQUEST_SORTING']._serialized_end=725
  _globals['_SEARCHGROUPSRESPONSE']._serialized_start=1431
  _globals['_SEARCHGROUPSRESPONSE']._serialized_end=1508
  _globals['_GETGROUPREQUEST']._serialized_start=1511
  _globals['_GETGROUPREQUEST']._serialized_end=1882
  _globals['_GROUPSERVICE']._serialized_start=1885
  _globals['_GROUPSERVICE']._serialized_end=2496
# @@protoc_insertion_point(module_scope)
